# apparat

A meta framework

## Description

* OO-Drawing

* Automation
    - nodes
    - stages
    - environment
    - container

* monitoring

* Audio

### Concepts
* FS based
* Auto reload with inotify

### Strong tool usage

* Full tool coverage
* Full paradigm coverage
** async
** multiprocessing
* pydantic
* functional
* opt in profiling
* on-the fly callstack
* flexible logging

* mypy / mypyc
* platform independent
* support IDEs
* pyenv
* pipenv
* CI integration Gitlab runner
* profiling
* logging
* doctest
* documentation

## Installation

## Usage


## Test and Deploy

Use the built-in continuous integration in GitLab.

- [ ] [Get started with GitLab CI/CD](https://docs.gitlab.com/ee/ci/quick_start/index.html)
- [ ] [Analyze your code for known vulnerabilities with Static Application Security Testing(SAST)](https://docs.gitlab.com/ee/user/application_security/sast/)
- [ ] [Deploy to Kubernetes, Amazon EC2, or Amazon ECS using Auto Deploy](https://docs.gitlab.com/ee/topics/autodevops/requirements.html)
- [ ] [Use pull-based deployments for improved Kubernetes management](https://docs.gitlab.com/ee/user/clusters/agent/)
- [ ] [Set up protected environments](https://docs.gitlab.com/ee/ci/environments/protected_environments.html)


## Support

## Roadmap

## Contributing

## Authors and acknowledgment

## License

## Project status

